quantizationtools.QGrid
=======================

.. abjad-lineage:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid

.. autoclass:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.distance
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.leaves
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.next_downbeat
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.offsets
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.pretty_rtm_format
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.root_node
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.rtm_format
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.fit_q_events
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.sort_q_events_by_index
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.subdivide_leaf
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.subdivide_leaves
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.__call__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.__ge__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.__getstate__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.__gt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.__le__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.__lt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.__repr__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.QGrid.__setstate__
   :noindex:
